package integration
import "github.com/google/trillian/integration"
Package integration contains some integration tests which are intended to serve as a way of checking that various top-level binaries work as intended, as well as providing a simple example of how to run and use the various servers.
Index ¶
- func RunLogIntegration(client trillian.TrillianLogClient, params TestParameters) error
- type TestParameters
Functions ¶
func RunLogIntegration ¶
func RunLogIntegration(client trillian.TrillianLogClient, params TestParameters) error
RunLogIntegration runs a log integration test using the given client and test parameters.
Types ¶
type TestParameters ¶
type TestParameters struct {
TreeID int64
CheckLogEmpty bool
QueueLeaves bool
AwaitSequencing bool
StartLeaf int64
LeafCount int64
UniqueLeaves int64
QueueBatchSize int
SequencerBatchSize int
ReadBatchSize int64
SequencingWaitTotal time.Duration
SequencingPollWait time.Duration
RPCRequestDeadline time.Duration
CustomLeafPrefix string
}
TestParameters bundles up all the settings for a test run
func DefaultTestParameters ¶
func DefaultTestParameters(treeID int64) TestParameters
DefaultTestParameters builds a TestParameters object for a normal test of the given log.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| integration/admin | Package admin contains integration tests for the Admin server. |
| integration/format | Package format contains an integration test which builds a log using an in-memory storage end-to-end, and makes sure the SubtreeProto storage format has no regressions. |
| integration/quota | Package quota contains quota-related integration tests. |
| integration/storagetest | Package storagetest contains tests and helpers for storage implementations. |
- Version
- v1.7.2 (latest)
- Published
- Apr 25, 2025
- Platform
- linux/amd64
- Imports
- 13 packages
- Last checked
- 4 months ago –
Tools for package owners.